@@ -20,9 +20,9 @@ test_that("draw.evaluated_1d_smooth() plots the smooth", {
 })
 
 test_that("draw.gam works with numeric select", {
-    plt <- draw(su_m_univar_4, select = 2)
+    plt <- draw(su_m_quick_eg1, select = 2)
     expect_doppelganger("draw gam smooth for selected smooth numeric", plt)
-    plt <- draw(su_m_univar_4, select = c(1,2))
+    plt <- draw(su_m_quick_eg1, select = c(1,2))
     expect_doppelganger("draw gam smooth for two selected smooths numeric", plt)
 })
 
@@ -42,17 +42,17 @@ the number of smooths in the model.", fixed = TRUE)
 })
 
 test_that("draw.gam works with character select", {
-    plt <- draw(su_m_univar_4, select = "s(x1)")
+    plt <- draw(su_m_quick_eg1, select = "s(x1)")
     expect_doppelganger("draw gam smooth for selected smooth character", plt)
-    plt <- draw(su_m_univar_4, select = c("s(x0)", "s(x1)"))
+    plt <- draw(su_m_quick_eg1, select = c("s(x0)", "s(x1)"))
     expect_doppelganger("draw gam smooth for two selected smooths character",
                         plt)
 })
 
 test_that("draw.gam works with logical select", {
-    plt <- draw(su_m_univar_4, select = c(TRUE, rep(FALSE, 3)))
+    plt <- draw(su_m_quick_eg1, select = c(TRUE, rep(FALSE, 3)))
     expect_doppelganger("draw gam smooth for selected smooth logical", plt)
-    plt <- draw(su_m_univar_4, select = rep(c(TRUE, FALSE), each = 2))
+    plt <- draw(su_m_quick_eg1, select = rep(c(TRUE, FALSE), each = 2))
     expect_doppelganger("draw gam smooth for two selected smooths logical", plt)
 })
 
@@ -81,6 +81,7 @@ test_that("draw.gam works with select and parametric", {
 
 test_that("draw.evaluated_2d_smooth() plots the smooth", {
     skip_on_os("mac")
+    skip_on_os("win") # failing for trivial diffs in contours
     withr::local_options(lifecycle_verbosity = "quiet")
     expect_silent(sm <- evaluate_smooth(su_m_bivar, "s(x,z)", n = 100))
     expect_silent(plt <- draw(sm))
@@ -118,18 +119,18 @@ test_that("draw.evaluated_2d_smooth() plots the SE", {
 })
 
 test_that("draw.gam() plots a simple multi-smooth AM", {
-    plt <- draw(su_m_univar_4)
+    plt <- draw(su_m_quick_eg1)
     expect_doppelganger("draw simple multi-smooth AM", plt)
 
-    plt <- draw(su_m_univar_4, scales = "fixed")
+    plt <- draw(su_m_quick_eg1, scales = "fixed")
     expect_doppelganger("draw simple multi-smooth AM with fixed scales", plt)
 })
 
 test_that("draw.gam() can draw partial residuals", {
-    plt <- draw(su_m_univar_4, residuals = TRUE)
+    plt <- draw(su_m_quick_eg1, residuals = TRUE, rug = FALSE)
     expect_doppelganger("draw simple partial residuals", plt)
 
-    plt <- draw(su_m_univar_4, residuals = TRUE, scales = "fixed")
+    plt <- draw(su_m_quick_eg1, residuals = TRUE, scales = "fixed", rug = FALSE)
     expect_doppelganger("draw simple partial residuals with fixed scales", plt)
 })
 
@@ -256,10 +257,10 @@ test_that("draw() works with factor-smooth interactions (bs = 'fs')", {
     p1 <- draw(sm)
     expect_doppelganger("draw.evaluated_fs_smooth", p1)
 
-    p2 <- draw(mod_fs, ncol = 2)
+    p2 <- draw(mod_fs, ncol = 2, rug = FALSE)
     expect_doppelganger("draw.gam model with fs smooth", p2)
 
-    p3 <- draw(mod_fs, ncol = 2, scales = "fixed")
+    p3 <- draw(mod_fs, ncol = 2, scales = "fixed", rug = FALSE)
     expect_doppelganger("draw model with fs smooth fixed scales", p3)
 })
 
@@ -321,12 +322,7 @@ test_that("draw() works with parametric terms", {
 })
 
 test_that("component-wise CIs work without seWithMean", {
-    withr::local_options(lifecycle_verbosity = "quiet")
-    sm <- evaluate_smooth(su_m_univar_4, "s(x3)", overall_uncertainty = FALSE)
-    plt <- draw(sm)
-    expect_doppelganger("draw selected smooth with overall uncertainty false", plt)
-
-    plt <- draw(su_m_univar_4, overall_uncertainty = FALSE)
+    plt <- draw(su_m_univar_4, overall_uncertainty = FALSE, rug = FALSE)
     expect_doppelganger("draw gam with overall_uncertainty false", plt)
 })
 
@@ -387,20 +383,20 @@ test_that("draw() works with a ziplss models; issue #45", {
 })
 
 test_that("draw works for sample_smooths objects", {
-    sm1 <- smooth_samples(su_m_univar_4, n = 15, seed = 23478)
-    plt <- draw(sm1, alpha = 0.7)
+    sm1 <- smooth_samples(su_m_univar_4, n = 15, seed = 23478, n_vals = 100)
+    plt <- draw(sm1, alpha = 0.7, n_samples = 15, seed = 2635)
     expect_doppelganger("draw smooth_samples for GAM m1", plt)
 
-    sm2 <- smooth_samples(su_m_bivar, n = 4, seed = 23478)
-    plt <- draw(sm2, alpha = 0.7)
+    sm2 <- smooth_samples(su_m_bivar, n = 4, seed = 23478, n_vals = 100)
+    plt <- draw(sm2, alpha = 0.7, n_samples = 4, seed = 2635)
     expect_doppelganger("draw smooth_samples for GAM m2", plt)
 
-    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478)
-    plt <- draw(sm3, alpha = 0.7)
+    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478, n_vals = 100)
+    plt <- draw(sm3, alpha = 0.7, n_samples = 15, seed = 2635)
     expect_doppelganger("draw smooth_samples for GAM m3", plt)
 
-    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478)
-    plt <- draw(sm3, alpha = 0.7, scales = "fixed", seed = 23478)
+    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478, n_vals = 100)
+    plt <- draw(sm3, alpha = 0.7, scales = "fixed", n_samples = 15, seed = 2635)
     expect_doppelganger("draw smooth_samples for GAM m3 fixed scales", plt)
 })
 
@@ -413,7 +409,7 @@ test_that("draw works for sample_smooths objects", {
 })
 
 test_that("draw works for sample_smooths objects with n_samples", {
-    sm1 <- smooth_samples(su_m_univar_4, n = 15, seed = 23478)
+    sm1 <- smooth_samples(su_m_univar_4, n = 15, seed = 23478, n_vals = 100)
     plt <- draw(sm1, alpha = 0.7, n_samples = 6)
     expect_doppelganger("draw smooth_samples for m1 n_samples", plt)
 
@@ -421,13 +417,13 @@ test_that("draw works for sample_smooths objects with n_samples", {
     plt <- draw(sm2, alpha = 0.7, n_samples = 2)
     expect_doppelganger("draw smooth_samples for m2 n_samples", plt)
 
-    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478)
+    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478, n_vals = 100)
     plt <- draw(sm3, alpha = 0.7, n_samples = 6)
     expect_doppelganger("draw smooth_samples for GAM n_samples", plt)
 })
 
 test_that("draw works for sample_smooths objects with user specified smooth", {
-    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478)
+    sm3 <- smooth_samples(su_m_factor_by, n = 15, seed = 23478, n_vals = 100)
     plt <- draw(sm3, select = "s(x0)", alpha = 0.7)
     expect_doppelganger("draw selected smooth_samples for GAM m3", plt)
 
@@ -449,19 +445,21 @@ test_that("draw.gam uses fixed scales if asked for them: #73", {
     skip_on_ci()
     df <- data_sim("eg1", n = 1000, seed = 1)
     m <- gam(y ~ s(x1) + s(x2) + ti(x1, x2), data = su_eg1, method = "REML")
-    plt <- draw(m, scales = "fixed")
+    plt <- draw(m, scales = "fixed", rug = FALSE)
     expect_doppelganger("issue 73 draw uses fixed scales if asked for them",
                                  plt)
 })
 
 test_that("draw.gam can take user specified scales", {
-    plt <- draw(su_m_bivar,
+    skip_on_os(os = "win")
+    skip_on_os(os = "mac") # trivial diffs in contours
+    plt <- draw(su_m_bivar, rug = FALSE,
                 continuous_fill = scale_fill_distiller(palette = "Spectral",
                                                        type = "div"))
     expect_doppelganger("draw 2d smooth with spectral palette", plt)
 
     skip_if(packageVersion("mgcv") < "1.8.36")
-    plt <- draw(mod_fs,
+    plt <- draw(mod_fs, rug = FALSE,
                 discrete_colour = scale_colour_viridis_d(option = "plasma"))
     expect_doppelganger("draw fs smooth with discrete plasma palette",
                                  plt)
@@ -512,10 +510,3 @@ test_that("draw.penalty_df works with normalization", {
     expect_doppelganger("draw penalty_df with single smooths normalized",
                         plt)
 })
-
-# Distributed lag models
-test_that("issue 116 - handle distributed lag models", {
-    plt <- draw(dlnm_m)
-    expect_doppelganger("draw distributed lag model issue 116",
-                        plt)
-})
